@@ -12,12 +12,13 @@ use utils::parse;
 const EXCHANGE_NAME: &str = "binance";
 
 #[test_case(MarketType::Spot, "BTCUSDT")]
-#[test_case(MarketType::InverseFuture, "BTCUSD_220325")]
+#[test_case(MarketType::InverseFuture, "BTCUSD_220624")]
 #[test_case(MarketType::LinearFuture, "BTCUSDT_220325")]
 #[test_case(MarketType::InverseSwap, "BTCUSD_PERP")]
 #[test_case(MarketType::LinearSwap, "BTCUSDT")]
-#[test_case(MarketType::EuropeanOption, "BTC-220429-50000-C"; "inconclusive")]
-fn test_crawl_trade(market_type: MarketType, symbol: &str) {
+// #[test_case(MarketType::EuropeanOption, "BTC-220429-50000-C"; "ignore")]
+#[tokio::test(flavor = "multi_thread")]
+async fn test_crawl_trade(market_type: MarketType, symbol: &str) {
     test_one_symbol!(
         crawl_trade,
         EXCHANGE_NAME,
@@ -28,12 +29,13 @@ fn test_crawl_trade(market_type: MarketType, symbol: &str) {
 }
 
 #[test_case(MarketType::Spot, "BTCUSDT")]
-#[test_case(MarketType::InverseFuture, "BTCUSD_220325")]
+#[test_case(MarketType::InverseFuture, "BTCUSD_220624")]
 #[test_case(MarketType::LinearFuture, "BTCUSDT_220325")]
 #[test_case(MarketType::InverseSwap, "BTCUSD_PERP")]
 #[test_case(MarketType::LinearSwap, "BTCUSDT")]
-#[test_case(MarketType::EuropeanOption, "BTC-220429-50000-C"; "inconclusive")]
-fn test_crawl_l2_event(market_type: MarketType, symbol: &str) {
+// #[test_case(MarketType::EuropeanOption, "BTC-220429-50000-C"; "ignore")]
+#[tokio::test(flavor = "multi_thread")]
+async fn test_crawl_l2_event(market_type: MarketType, symbol: &str) {
     test_one_symbol!(
         crawl_l2_event,
         EXCHANGE_NAME,
@@ -44,12 +46,13 @@ fn test_crawl_l2_event(market_type: MarketType, symbol: &str) {
 }
 
 #[test_case(MarketType::Spot, "BTCUSDT")]
-#[test_case(MarketType::InverseFuture, "BTCUSD_220325")]
+#[test_case(MarketType::InverseFuture, "BTCUSD_220624")]
 #[test_case(MarketType::LinearFuture, "BTCUSDT_220325")]
 #[test_case(MarketType::InverseSwap, "BTCUSD_PERP")]
 #[test_case(MarketType::LinearSwap, "BTCUSDT")]
-#[test_case(MarketType::EuropeanOption, "BTC-220429-50000-C"; "inconclusive")]
-fn test_crawl_bbo(market_type: MarketType, symbol: &str) {
+// #[test_case(MarketType::EuropeanOption, "BTC-220429-50000-C"; "ignore")]
+#[tokio::test(flavor = "multi_thread")]
+async fn test_crawl_bbo(market_type: MarketType, symbol: &str) {
     test_one_symbol!(
         crawl_bbo,
         EXCHANGE_NAME,
@@ -60,12 +63,13 @@ fn test_crawl_bbo(market_type: MarketType, symbol: &str) {
 }
 
 #[test_case(MarketType::Spot, "BTCUSDT")]
-#[test_case(MarketType::InverseFuture, "BTCUSD_220325")]
+#[test_case(MarketType::InverseFuture, "BTCUSD_220624")]
 #[test_case(MarketType::LinearFuture, "BTCUSDT_220325")]
 #[test_case(MarketType::InverseSwap, "BTCUSD_PERP")]
 #[test_case(MarketType::LinearSwap, "BTCUSDT")]
-#[test_case(MarketType::EuropeanOption, "BTC-220429-50000-C"; "inconclusive")]
-fn test_crawl_l2_topk(market_type: MarketType, symbol: &str) {
+// #[test_case(MarketType::EuropeanOption, "BTC-220429-50000-C"; "ignore")]
+#[tokio::test(flavor = "multi_thread")]
+async fn test_crawl_l2_topk(market_type: MarketType, symbol: &str) {
     test_one_symbol!(
         crawl_l2_topk,
         EXCHANGE_NAME,
@@ -75,14 +79,14 @@ fn test_crawl_l2_topk(market_type: MarketType, symbol: &str) {
     )
 }
 
-#[test_case(MarketType::Spot, "BTCUSDT"; "inconclusive since spot market has too many symbols")]
-#[test_case(MarketType::InverseFuture, "BTCUSD_220325")]
+#[test_case(MarketType::Spot, "BTCUSDT")]
+#[test_case(MarketType::InverseFuture, "BTCUSD_220624")]
 #[test_case(MarketType::LinearFuture, "BTCUSDT_220325")]
 #[test_case(MarketType::InverseSwap, "BTCUSD_PERP")]
 #[test_case(MarketType::LinearSwap, "BTCUSDT")]
-#[test_case(MarketType::EuropeanOption, "BTC-220429-50000-C"; "inconclusive since option market has too many symbols")]
+#[test_case(MarketType::EuropeanOption, "BTC-220429-50000-C")]
 fn test_crawl_l2_snapshot(market_type: MarketType, symbol: &str) {
-    test_one_symbol!(
+    test_crawl_restful!(
         crawl_l2_snapshot,
         EXCHANGE_NAME,
         market_type,
@@ -96,8 +100,9 @@ fn test_crawl_l2_snapshot(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::LinearFuture)]
 #[test_case(MarketType::InverseSwap)]
 #[test_case(MarketType::LinearSwap)]
+#[test_case(MarketType::EuropeanOption)]
 fn test_crawl_l2_snapshot_without_symbol(market_type: MarketType) {
-    test_all_symbols!(
+    test_crawl_restful_all_symbols!(
         crawl_l2_snapshot,
         EXCHANGE_NAME,
         market_type,
@@ -106,12 +111,13 @@ fn test_crawl_l2_snapshot_without_symbol(market_type: MarketType) {
 }
 
 #[test_case(MarketType::Spot, "BTCUSDT")]
-#[test_case(MarketType::InverseFuture, "BTCUSD_220325")]
+#[test_case(MarketType::InverseFuture, "BTCUSD_220624")]
 #[test_case(MarketType::LinearFuture, "BTCUSDT_220325")]
 #[test_case(MarketType::InverseSwap, "BTCUSD_PERP")]
 #[test_case(MarketType::LinearSwap, "BTCUSDT")]
-#[test_case(MarketType::EuropeanOption, "BTC-220429-50000-C"; "inconclusive")]
-fn test_crawl_ticker(market_type: MarketType, symbol: &str) {
+// #[test_case(MarketType::EuropeanOption, "BTC-220429-50000-C"; "ignore")]
+#[tokio::test(flavor = "multi_thread")]
+async fn test_crawl_ticker(market_type: MarketType, symbol: &str) {
     test_one_symbol!(
         crawl_ticker,
         EXCHANGE_NAME,
@@ -123,7 +129,8 @@ fn test_crawl_ticker(market_type: MarketType, symbol: &str) {
 
 #[test_case(MarketType::InverseSwap, "BTCUSD_PERP")]
 #[test_case(MarketType::LinearSwap, "BTCUSDT")]
-fn test_crawl_funding_rate(market_type: MarketType, symbol: &str) {
+#[tokio::test(flavor = "multi_thread")]
+async fn test_crawl_funding_rate(market_type: MarketType, symbol: &str) {
     test_one_symbol!(
         crawl_funding_rate,
         EXCHANGE_NAME,
@@ -138,16 +145,18 @@ fn test_crawl_funding_rate(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::LinearFuture)]
 #[test_case(MarketType::InverseSwap)]
 #[test_case(MarketType::LinearSwap)]
-fn test_crawl_candlestick(market_type: MarketType) {
+#[tokio::test(flavor = "multi_thread")]
+async fn test_crawl_candlestick(market_type: MarketType) {
     gen_test_crawl_candlestick!(EXCHANGE_NAME, market_type)
 }
 
-#[test_case(MarketType::Spot, "BTCUSDT")]
-#[test_case(MarketType::InverseFuture, "BTCUSD_220325")]
-#[test_case(MarketType::LinearFuture, "BTCUSDT_220325")]
-#[test_case(MarketType::InverseSwap, "BTCUSD_PERP")]
-#[test_case(MarketType::LinearSwap, "BTCUSDT")]
-#[test_case(MarketType::EuropeanOption, "BTC-220429-50000-C"; "inconclusive")]
-fn test_subscribe_symbol(market_type: MarketType, symbol: &str) {
-    gen_test_subscribe_symbol!(EXCHANGE_NAME, market_type, symbol)
-}
+// #[test_case(MarketType::Spot, "BTCUSDT")]
+// #[test_case(MarketType::InverseFuture, "BTCUSD_220624")]
+// #[test_case(MarketType::LinearFuture, "BTCUSDT_220325")]
+// #[test_case(MarketType::InverseSwap, "BTCUSD_PERP")]
+// #[test_case(MarketType::LinearSwap, "BTCUSDT")]
+// #[test_case(MarketType::EuropeanOption, "BTC-220429-50000-C"; "ignore")]
+// #[tokio::test(flavor = "multi_thread")]
+// async fn test_subscribe_symbol(market_type: MarketType, symbol: &str) {
+//     gen_test_subscribe_symbol!(EXCHANGE_NAME, market_type, symbol)
+// }
