@@ -11,7 +11,8 @@ use utils::parse;
 const EXCHANGE_NAME: &str = "coinbase_pro";
 
 #[test_case(MarketType::Spot, "BTC-USD")]
-fn test_crawl_trade(market_type: MarketType, symbol: &str) {
+#[tokio::test(flavor = "multi_thread")]
+async fn test_crawl_trade(market_type: MarketType, symbol: &str) {
     test_one_symbol!(
         crawl_trade,
         EXCHANGE_NAME,
@@ -22,7 +23,8 @@ fn test_crawl_trade(market_type: MarketType, symbol: &str) {
 }
 
 #[test_case(MarketType::Spot, "BTC-USD")]
-fn test_crawl_l2_event(market_type: MarketType, symbol: &str) {
+#[tokio::test(flavor = "multi_thread")]
+async fn test_crawl_l2_event(market_type: MarketType, symbol: &str) {
     test_one_symbol!(
         crawl_l2_event,
         EXCHANGE_NAME,
@@ -34,7 +36,7 @@ fn test_crawl_l2_event(market_type: MarketType, symbol: &str) {
 
 #[test_case(MarketType::Spot, "BTC-USD")]
 fn test_crawl_l2_snapshot(market_type: MarketType, symbol: &str) {
-    test_one_symbol!(
+    test_crawl_restful!(
         crawl_l2_snapshot,
         EXCHANGE_NAME,
         market_type,
@@ -45,7 +47,7 @@ fn test_crawl_l2_snapshot(market_type: MarketType, symbol: &str) {
 
 #[test_case(MarketType::Spot)]
 fn test_crawl_l2_snapshot_without_symbol(market_type: MarketType) {
-    test_all_symbols!(
+    test_crawl_restful_all_symbols!(
         crawl_l2_snapshot,
         EXCHANGE_NAME,
         market_type,
@@ -54,7 +56,8 @@ fn test_crawl_l2_snapshot_without_symbol(market_type: MarketType) {
 }
 
 #[test_case(MarketType::Spot, "BTC-USD")]
-fn test_crawl_l3_event(market_type: MarketType, symbol: &str) {
+#[tokio::test(flavor = "multi_thread")]
+async fn test_crawl_l3_event(market_type: MarketType, symbol: &str) {
     test_one_symbol!(
         crawl_l3_event,
         EXCHANGE_NAME,
@@ -65,8 +68,9 @@ fn test_crawl_l3_event(market_type: MarketType, symbol: &str) {
 }
 
 #[test_case(MarketType::Spot, "BTC-USD")]
-fn test_crawl_l3_snapshot(market_type: MarketType, symbol: &str) {
-    test_one_symbol!(
+#[tokio::test(flavor = "multi_thread")]
+async fn test_crawl_l3_snapshot(market_type: MarketType, symbol: &str) {
+    test_crawl_restful!(
         crawl_l3_snapshot,
         EXCHANGE_NAME,
         market_type,
@@ -76,7 +80,8 @@ fn test_crawl_l3_snapshot(market_type: MarketType, symbol: &str) {
 }
 
 #[test_case(MarketType::Spot, "BTC-USD")]
-fn test_crawl_ticker(market_type: MarketType, symbol: &str) {
+#[tokio::test(flavor = "multi_thread")]
+async fn test_crawl_ticker(market_type: MarketType, symbol: &str) {
     test_one_symbol!(
         crawl_ticker,
         EXCHANGE_NAME,
