@@ -13,7 +13,8 @@ const EXCHANGE_NAME: &str = "deribit";
 #[test_case(MarketType::InverseSwap, "BTC-PERPETUAL")]
 #[test_case(MarketType::InverseFuture, "BTC-24JUN22")]
 #[test_case(MarketType::EuropeanOption, "BTC-24JUN22-40000-C"; "inconclusive")]
-fn test_crawl_trade(market_type: MarketType, symbol: &str) {
+#[tokio::test(flavor = "multi_thread")]
+async fn test_crawl_trade(market_type: MarketType, symbol: &str) {
     test_one_symbol!(
         crawl_trade,
         EXCHANGE_NAME,
@@ -26,14 +27,16 @@ fn test_crawl_trade(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::InverseSwap)]
 #[test_case(MarketType::InverseFuture)]
 #[test_case(MarketType::EuropeanOption)]
-fn test_crawl_trade_all(market_type: MarketType) {
+#[tokio::test(flavor = "multi_thread")]
+async fn test_crawl_trade_all(market_type: MarketType) {
     test_all_symbols!(crawl_trade, EXCHANGE_NAME, market_type, MessageType::Trade)
 }
 
 #[test_case(MarketType::InverseSwap, "BTC-PERPETUAL")]
 #[test_case(MarketType::InverseFuture, "BTC-24JUN22")]
 #[test_case(MarketType::EuropeanOption, "BTC-24JUN22-40000-C")]
-fn test_crawl_l2_event(market_type: MarketType, symbol: &str) {
+#[tokio::test(flavor = "multi_thread")]
+async fn test_crawl_l2_event(market_type: MarketType, symbol: &str) {
     test_one_symbol!(
         crawl_l2_event,
         EXCHANGE_NAME,
@@ -46,7 +49,8 @@ fn test_crawl_l2_event(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::InverseSwap, "BTC-PERPETUAL")]
 #[test_case(MarketType::InverseFuture, "BTC-24JUN22")]
 #[test_case(MarketType::EuropeanOption, "BTC-24JUN22-40000-C")]
-fn test_crawl_bbo(market_type: MarketType, symbol: &str) {
+#[tokio::test(flavor = "multi_thread")]
+async fn test_crawl_bbo(market_type: MarketType, symbol: &str) {
     test_one_symbol!(
         crawl_bbo,
         EXCHANGE_NAME,
@@ -59,7 +63,8 @@ fn test_crawl_bbo(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::InverseSwap, "BTC-PERPETUAL")]
 #[test_case(MarketType::InverseFuture, "BTC-24JUN22")]
 #[test_case(MarketType::EuropeanOption, "BTC-24JUN22-40000-C")]
-fn test_crawl_l2_topk(market_type: MarketType, symbol: &str) {
+#[tokio::test(flavor = "multi_thread")]
+async fn test_crawl_l2_topk(market_type: MarketType, symbol: &str) {
     test_one_symbol!(
         crawl_l2_topk,
         EXCHANGE_NAME,
@@ -73,7 +78,7 @@ fn test_crawl_l2_topk(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::InverseFuture, "BTC-24JUN22")]
 #[test_case(MarketType::EuropeanOption, "BTC-24JUN22-40000-C")]
 fn test_crawl_l2_snapshot(market_type: MarketType, symbol: &str) {
-    test_one_symbol!(
+    test_crawl_restful!(
         crawl_l2_snapshot,
         EXCHANGE_NAME,
         market_type,
@@ -86,7 +91,7 @@ fn test_crawl_l2_snapshot(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::InverseFuture)]
 #[test_case(MarketType::EuropeanOption; "inconclusive")]
 fn test_crawl_l2_snapshot_without_symbol(market_type: MarketType) {
-    test_all_symbols!(
+    test_crawl_restful_all_symbols!(
         crawl_l2_snapshot,
         EXCHANGE_NAME,
         market_type,
@@ -97,7 +102,8 @@ fn test_crawl_l2_snapshot_without_symbol(market_type: MarketType) {
 #[test_case(MarketType::InverseSwap, "BTC-PERPETUAL")]
 #[test_case(MarketType::InverseFuture, "BTC-24JUN22")]
 #[test_case(MarketType::EuropeanOption, "BTC-24JUN22-40000-C")]
-fn test_crawl_ticker(market_type: MarketType, symbol: &str) {
+#[tokio::test(flavor = "multi_thread")]
+async fn test_crawl_ticker(market_type: MarketType, symbol: &str) {
     test_one_symbol!(
         crawl_ticker,
         EXCHANGE_NAME,
@@ -110,13 +116,14 @@ fn test_crawl_ticker(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::InverseSwap)]
 #[test_case(MarketType::InverseFuture)]
 #[test_case(MarketType::EuropeanOption)]
-fn test_crawl_candlestick(market_type: MarketType) {
+#[tokio::test(flavor = "multi_thread")]
+async fn test_crawl_candlestick(market_type: MarketType) {
     gen_test_crawl_candlestick!(EXCHANGE_NAME, market_type)
 }
 
-#[test_case(MarketType::InverseSwap, "BTC-PERPETUAL")]
-#[test_case(MarketType::InverseFuture, "BTC-24JUN22")]
-#[test_case(MarketType::EuropeanOption, "BTC-24JUN22-40000-C")]
-fn test_subscribe_symbol(market_type: MarketType, symbol: &str) {
-    gen_test_subscribe_symbol!(EXCHANGE_NAME, market_type, symbol)
-}
+// #[test_case(MarketType::InverseSwap, "BTC-PERPETUAL")]
+// #[test_case(MarketType::InverseFuture, "BTC-24JUN22")]
+// #[test_case(MarketType::EuropeanOption, "BTC-24JUN22-40000-C")]
+// fn test_subscribe_symbol(market_type: MarketType, symbol: &str) {
+//     gen_test_subscribe_symbol!(EXCHANGE_NAME, market_type, symbol)
+// }
