@@ -13,16 +13,18 @@ const EXCHANGE_NAME: &str = "gate";
 #[test_case(MarketType::Spot)]
 #[test_case(MarketType::InverseSwap)]
 #[test_case(MarketType::LinearSwap)]
-#[test_case(MarketType::LinearFuture; "inconclusive")]
-fn test_crawl_trade_all(market_type: MarketType) {
+// #[test_case(MarketType::LinearFuture; "ignore")]
+#[tokio::test(flavor = "multi_thread")]
+async fn test_crawl_trade_all(market_type: MarketType) {
     test_all_symbols!(crawl_trade, EXCHANGE_NAME, market_type, MessageType::Trade)
 }
 
 #[test_case(MarketType::Spot, "BTC_USDT")]
 #[test_case(MarketType::InverseSwap, "BTC_USD")]
 #[test_case(MarketType::LinearSwap, "BTC_USDT")]
-#[test_case(MarketType::LinearFuture, "BTC_USDT_20220325"; "inconclusive")]
-fn test_crawl_trade(market_type: MarketType, symbol: &str) {
+// #[test_case(MarketType::LinearFuture, "BTC_USDT_20220325"; "ignore")]
+#[tokio::test(flavor = "multi_thread")]
+async fn test_crawl_trade(market_type: MarketType, symbol: &str) {
     test_one_symbol!(
         crawl_trade,
         EXCHANGE_NAME,
@@ -35,8 +37,9 @@ fn test_crawl_trade(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::Spot, "BTC_USDT")]
 #[test_case(MarketType::InverseSwap, "BTC_USD")]
 #[test_case(MarketType::LinearSwap, "BTC_USDT")]
-#[test_case(MarketType::LinearFuture, "BTC_USDT_20220325"; "inconclusive")]
-fn test_crawl_l2_event(market_type: MarketType, symbol: &str) {
+// #[test_case(MarketType::LinearFuture, "BTC_USDT_20220325"; "ignore")]
+#[tokio::test(flavor = "multi_thread")]
+async fn test_crawl_l2_event(market_type: MarketType, symbol: &str) {
     test_one_symbol!(
         crawl_l2_event,
         EXCHANGE_NAME,
@@ -49,7 +52,8 @@ fn test_crawl_l2_event(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::Spot, "BTC_USDT")]
 #[test_case(MarketType::InverseSwap, "BTC_USD")]
 #[test_case(MarketType::LinearSwap, "BTC_USDT")]
-fn test_crawl_bbo(market_type: MarketType, symbol: &str) {
+#[tokio::test(flavor = "multi_thread")]
+async fn test_crawl_bbo(market_type: MarketType, symbol: &str) {
     test_one_symbol!(
         crawl_bbo,
         EXCHANGE_NAME,
@@ -62,9 +66,9 @@ fn test_crawl_bbo(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::Spot, "BTC_USDT")]
 #[test_case(MarketType::InverseSwap, "BTC_USD")]
 #[test_case(MarketType::LinearSwap, "BTC_USDT")]
-#[test_case(MarketType::LinearFuture, "BTC_USDT_20220325"; "inconclusive")]
+// #[test_case(MarketType::LinearFuture, "BTC_USDT_20220325"; "ignore")]
 fn test_crawl_l2_snapshot(market_type: MarketType, symbol: &str) {
-    test_one_symbol!(
+    test_crawl_restful!(
         crawl_l2_snapshot,
         EXCHANGE_NAME,
         market_type,
@@ -78,7 +82,7 @@ fn test_crawl_l2_snapshot(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::LinearSwap)]
 #[test_case(MarketType::LinearFuture)]
 fn test_crawl_l2_snapshot_without_symbol(market_type: MarketType) {
-    test_all_symbols!(
+    test_crawl_restful_all_symbols!(
         crawl_l2_snapshot,
         EXCHANGE_NAME,
         market_type,
@@ -89,8 +93,9 @@ fn test_crawl_l2_snapshot_without_symbol(market_type: MarketType) {
 #[test_case(MarketType::Spot, "BTC_USDT")]
 #[test_case(MarketType::InverseSwap, "BTC_USD")]
 #[test_case(MarketType::LinearSwap, "BTC_USDT")]
-#[test_case(MarketType::LinearFuture, "BTC_USDT_20220325"; "inconclusive")]
-fn test_crawl_ticker(market_type: MarketType, symbol: &str) {
+// #[test_case(MarketType::LinearFuture, "BTC_USDT_20220325"; "ignore")]
+#[tokio::test(flavor = "multi_thread")]
+async fn test_crawl_ticker(market_type: MarketType, symbol: &str) {
     test_one_symbol!(
         crawl_ticker,
         EXCHANGE_NAME,
@@ -100,10 +105,11 @@ fn test_crawl_ticker(market_type: MarketType, symbol: &str) {
     )
 }
 
-#[test_case(MarketType::Spot)]
+// #[test_case(MarketType::Spot)] // TODO: gate spot candlestick channel doesn't send any messages
 #[test_case(MarketType::InverseSwap)]
 #[test_case(MarketType::LinearSwap)]
-#[test_case(MarketType::LinearFuture; "inconclusive because linear_future takes too long")]
-fn test_crawl_candlestick(market_type: MarketType) {
+// #[test_case(MarketType::LinearFuture; "ignored because linear_future takes too long")]
+#[tokio::test(flavor = "multi_thread", worker_threads = 16)]
+async fn test_crawl_candlestick(market_type: MarketType) {
     gen_test_crawl_candlestick!(EXCHANGE_NAME, market_type)
 }
