@@ -15,7 +15,8 @@ const EXCHANGE_NAME: &str = "huobi";
 #[test_case(MarketType::InverseSwap, "BTC-USD")]
 #[test_case(MarketType::LinearSwap, "BTC-USDT")]
 #[test_case(MarketType::EuropeanOption, "BTC-USDT-210625-P-27000"; "inconclusive")]
-fn test_crawl_trade(market_type: MarketType, symbol: &str) {
+#[tokio::test(flavor = "multi_thread")]
+async fn test_crawl_trade(market_type: MarketType, symbol: &str) {
     test_one_symbol!(
         crawl_trade,
         EXCHANGE_NAME,
@@ -30,7 +31,8 @@ fn test_crawl_trade(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::InverseSwap, "BTC-USD")]
 #[test_case(MarketType::LinearSwap, "BTC-USDT")]
 #[test_case(MarketType::EuropeanOption, "BTC-USDT-210625-P-27000"; "inconclusive")]
-fn test_crawl_l2_event(market_type: MarketType, symbol: &str) {
+#[tokio::test(flavor = "multi_thread")]
+async fn test_crawl_l2_event(market_type: MarketType, symbol: &str) {
     test_one_symbol!(
         crawl_l2_event,
         EXCHANGE_NAME,
@@ -45,7 +47,8 @@ fn test_crawl_l2_event(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::InverseSwap, "BTC-USD")]
 #[test_case(MarketType::LinearSwap, "BTC-USDT")]
 #[test_case(MarketType::EuropeanOption, "BTC-USDT-210625-P-27000"; "inconclusive")]
-fn test_crawl_bbo(market_type: MarketType, symbol: &str) {
+#[tokio::test(flavor = "multi_thread")]
+async fn test_crawl_bbo(market_type: MarketType, symbol: &str) {
     test_one_symbol!(
         crawl_bbo,
         EXCHANGE_NAME,
@@ -60,7 +63,8 @@ fn test_crawl_bbo(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::InverseSwap, "BTC-USD")]
 #[test_case(MarketType::LinearSwap, "BTC-USDT")]
 #[test_case(MarketType::EuropeanOption, "BTC-USDT-210625-P-27000"; "inconclusive")]
-fn test_crawl_l2_topk(market_type: MarketType, symbol: &str) {
+#[tokio::test(flavor = "multi_thread")]
+async fn test_crawl_l2_topk(market_type: MarketType, symbol: &str) {
     test_one_symbol!(
         crawl_l2_topk,
         EXCHANGE_NAME,
@@ -76,7 +80,7 @@ fn test_crawl_l2_topk(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::LinearSwap, "BTC-USDT")]
 #[test_case(MarketType::EuropeanOption, "BTC-USDT-210625-P-27000"; "inconclusive")]
 fn test_crawl_l2_snapshot(market_type: MarketType, symbol: &str) {
-    test_one_symbol!(
+    test_crawl_restful!(
         crawl_l2_snapshot,
         EXCHANGE_NAME,
         market_type,
@@ -91,7 +95,7 @@ fn test_crawl_l2_snapshot(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::LinearSwap)]
 #[test_case(MarketType::EuropeanOption; "inconclusive")]
 fn test_crawl_l2_snapshot_without_symbol(market_type: MarketType) {
-    test_all_symbols!(
+    test_crawl_restful_all_symbols!(
         crawl_l2_snapshot,
         EXCHANGE_NAME,
         market_type,
@@ -101,7 +105,8 @@ fn test_crawl_l2_snapshot_without_symbol(market_type: MarketType) {
 
 #[test_case(MarketType::InverseSwap, "BTC-USD")]
 #[test_case(MarketType::LinearSwap, "BTC-USDT")]
-fn test_crawl_funding_rate(market_type: MarketType, symbol: &str) {
+#[tokio::test(flavor = "multi_thread")]
+async fn test_crawl_funding_rate(market_type: MarketType, symbol: &str) {
     test_one_symbol!(
         crawl_funding_rate,
         EXCHANGE_NAME,
@@ -116,7 +121,8 @@ fn test_crawl_funding_rate(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::InverseSwap, "BTC-USD")]
 #[test_case(MarketType::LinearSwap, "BTC-USDT")]
 #[test_case(MarketType::EuropeanOption, "BTC-USDT-210625-P-27000"; "inconclusive")]
-fn test_crawl_ticker(market_type: MarketType, symbol: &str) {
+#[tokio::test(flavor = "multi_thread")]
+async fn test_crawl_ticker(market_type: MarketType, symbol: &str) {
     test_one_symbol!(
         crawl_ticker,
         EXCHANGE_NAME,
@@ -131,14 +137,15 @@ fn test_crawl_ticker(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::InverseSwap)]
 #[test_case(MarketType::LinearSwap)]
 #[test_case(MarketType::EuropeanOption; "inconclusive")]
-fn test_crawl_candlestick(market_type: MarketType) {
+#[tokio::test(flavor = "multi_thread")]
+async fn test_crawl_candlestick(market_type: MarketType) {
     gen_test_crawl_candlestick!(EXCHANGE_NAME, market_type)
 }
 
-#[test_case(MarketType::Spot, "btcusdt")]
-#[test_case(MarketType::InverseFuture, "BTC_CQ")]
-#[test_case(MarketType::InverseSwap, "BTC-USD")]
-#[test_case(MarketType::LinearSwap, "BTC-USDT")]
-fn test_subscribe_symbol(market_type: MarketType, symbol: &str) {
-    gen_test_subscribe_symbol!(EXCHANGE_NAME, market_type, symbol)
-}
+// #[test_case(MarketType::Spot, "btcusdt")]
+// #[test_case(MarketType::InverseFuture, "BTC_CQ")]
+// #[test_case(MarketType::InverseSwap, "BTC-USD")]
+// #[test_case(MarketType::LinearSwap, "BTC-USDT")]
+// fn test_subscribe_symbol(market_type: MarketType, symbol: &str) {
+//     gen_test_subscribe_symbol!(EXCHANGE_NAME, market_type, symbol)
+// }
