@@ -13,7 +13,8 @@ const EXCHANGE_NAME: &str = "kraken";
 #[test_case(MarketType::Spot, "XBT/USD")]
 #[test_case(MarketType::InverseFuture, "FI_XBTUSD_220624")]
 #[test_case(MarketType::InverseSwap, "PI_XBTUSD")]
-fn test_crawl_trade(market_type: MarketType, symbol: &str) {
+#[tokio::test(flavor = "multi_thread")]
+async fn test_crawl_trade(market_type: MarketType, symbol: &str) {
     test_one_symbol!(
         crawl_trade,
         EXCHANGE_NAME,
@@ -26,7 +27,8 @@ fn test_crawl_trade(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::Spot, "XBT/USD")]
 #[test_case(MarketType::InverseFuture, "FI_XBTUSD_220624")]
 #[test_case(MarketType::InverseSwap, "PI_XBTUSD")]
-fn test_crawl_l2_event(market_type: MarketType, symbol: &str) {
+#[tokio::test(flavor = "multi_thread")]
+async fn test_crawl_l2_event(market_type: MarketType, symbol: &str) {
     test_one_symbol!(
         crawl_l2_event,
         EXCHANGE_NAME,
@@ -37,7 +39,8 @@ fn test_crawl_l2_event(market_type: MarketType, symbol: &str) {
 }
 
 #[test_case(MarketType::Spot, "XBT/USD")]
-fn test_crawl_bbo(market_type: MarketType, symbol: &str) {
+#[tokio::test(flavor = "multi_thread")]
+async fn test_crawl_bbo(market_type: MarketType, symbol: &str) {
     test_one_symbol!(
         crawl_bbo,
         EXCHANGE_NAME,
@@ -51,7 +54,7 @@ fn test_crawl_bbo(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::InverseFuture, "FI_XBTUSD_220624")]
 #[test_case(MarketType::InverseSwap, "PI_XBTUSD")]
 fn test_crawl_l2_snapshot(market_type: MarketType, symbol: &str) {
-    test_one_symbol!(
+    test_crawl_restful!(
         crawl_l2_snapshot,
         EXCHANGE_NAME,
         market_type,
@@ -64,7 +67,7 @@ fn test_crawl_l2_snapshot(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::InverseFuture)]
 #[test_case(MarketType::InverseSwap)]
 fn test_crawl_l2_snapshot_without_symbol(market_type: MarketType) {
-    test_all_symbols!(
+    test_crawl_restful_all_symbols!(
         crawl_l2_snapshot,
         EXCHANGE_NAME,
         market_type,
@@ -75,7 +78,8 @@ fn test_crawl_l2_snapshot_without_symbol(market_type: MarketType) {
 #[test_case(MarketType::Spot, "XBT/USD")]
 #[test_case(MarketType::InverseFuture, "FI_XBTUSD_220624")]
 #[test_case(MarketType::InverseSwap, "PI_XBTUSD")]
-fn test_crawl_ticker(market_type: MarketType, symbol: &str) {
+#[tokio::test(flavor = "multi_thread")]
+async fn test_crawl_ticker(market_type: MarketType, symbol: &str) {
     test_one_symbol!(
         crawl_ticker,
         EXCHANGE_NAME,
@@ -86,6 +90,7 @@ fn test_crawl_ticker(market_type: MarketType, symbol: &str) {
 }
 
 #[test_case(MarketType::Spot)]
-fn test_crawl_candlestick(market_type: MarketType) {
+#[tokio::test(flavor = "multi_thread")]
+async fn test_crawl_candlestick(market_type: MarketType) {
     gen_test_crawl_candlestick!(EXCHANGE_NAME, market_type)
 }
