@@ -13,8 +13,9 @@ const EXCHANGE_NAME: &str = "kucoin";
 #[test_case(MarketType::Spot, "BTC-USDT")]
 #[test_case(MarketType::InverseSwap, "XBTUSDM")]
 #[test_case(MarketType::LinearSwap, "XBTUSDTM")]
-#[test_case(MarketType::InverseFuture, "XBTMH22"; "inconclusive")]
-fn test_crawl_trade(market_type: MarketType, symbol: &str) {
+// #[test_case(MarketType::InverseFuture, "XBTMM22"; "ignore")]
+#[tokio::test(flavor = "multi_thread")]
+async fn test_crawl_trade(market_type: MarketType, symbol: &str) {
     test_one_symbol!(
         crawl_trade,
         EXCHANGE_NAME,
@@ -27,8 +28,9 @@ fn test_crawl_trade(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::Spot, "BTC-USDT")]
 #[test_case(MarketType::InverseSwap, "XBTUSDM")]
 #[test_case(MarketType::LinearSwap, "XBTUSDTM")]
-#[test_case(MarketType::InverseFuture, "XBTMH22")]
-fn test_crawl_l2_event(market_type: MarketType, symbol: &str) {
+#[test_case(MarketType::InverseFuture, "XBTMM22")]
+#[tokio::test(flavor = "multi_thread")]
+async fn test_crawl_l2_event(market_type: MarketType, symbol: &str) {
     test_one_symbol!(
         crawl_l2_event,
         EXCHANGE_NAME,
@@ -41,8 +43,9 @@ fn test_crawl_l2_event(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::Spot, "BTC-USDT")]
 #[test_case(MarketType::InverseSwap, "XBTUSDM")]
 #[test_case(MarketType::LinearSwap, "XBTUSDTM")]
-#[test_case(MarketType::InverseFuture, "XBTMH22")]
-fn test_crawl_bbo(market_type: MarketType, symbol: &str) {
+#[test_case(MarketType::InverseFuture, "XBTMM22")]
+#[tokio::test(flavor = "multi_thread")]
+async fn test_crawl_bbo(market_type: MarketType, symbol: &str) {
     test_one_symbol!(
         crawl_bbo,
         EXCHANGE_NAME,
@@ -55,8 +58,9 @@ fn test_crawl_bbo(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::Spot, "BTC-USDT")]
 #[test_case(MarketType::InverseSwap, "XBTUSDM")]
 #[test_case(MarketType::LinearSwap, "XBTUSDTM")]
-#[test_case(MarketType::InverseFuture, "XBTMH22")]
-fn test_crawl_l2_topk(market_type: MarketType, symbol: &str) {
+#[test_case(MarketType::InverseFuture, "XBTMM22")]
+#[tokio::test(flavor = "multi_thread")]
+async fn test_crawl_l2_topk(market_type: MarketType, symbol: &str) {
     test_one_symbol!(
         crawl_l2_topk,
         EXCHANGE_NAME,
@@ -69,8 +73,9 @@ fn test_crawl_l2_topk(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::Spot, "BTC-USDT")]
 #[test_case(MarketType::InverseSwap, "XBTUSDM")]
 #[test_case(MarketType::LinearSwap, "XBTUSDTM")]
-#[test_case(MarketType::InverseFuture, "XBTMH22")]
-fn test_crawl_l3_event(market_type: MarketType, symbol: &str) {
+#[test_case(MarketType::InverseFuture, "XBTMM22")]
+#[tokio::test(flavor = "multi_thread")]
+async fn test_crawl_l3_event(market_type: MarketType, symbol: &str) {
     test_one_symbol!(
         crawl_l3_event,
         EXCHANGE_NAME,
@@ -83,9 +88,9 @@ fn test_crawl_l3_event(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::Spot, "BTC-USDT")]
 #[test_case(MarketType::InverseSwap, "XBTUSDM")]
 #[test_case(MarketType::LinearSwap, "XBTUSDTM")]
-#[test_case(MarketType::InverseFuture, "XBTMH22")]
+#[test_case(MarketType::InverseFuture, "XBTMM22")]
 fn test_crawl_l2_snapshot(market_type: MarketType, symbol: &str) {
-    test_one_symbol!(
+    test_crawl_restful!(
         crawl_l2_snapshot,
         EXCHANGE_NAME,
         market_type,
@@ -99,7 +104,7 @@ fn test_crawl_l2_snapshot(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::LinearSwap)]
 #[test_case(MarketType::InverseFuture)]
 fn test_crawl_l2_snapshot_without_symbol(market_type: MarketType) {
-    test_all_symbols!(
+    test_crawl_restful_all_symbols!(
         crawl_l2_snapshot,
         EXCHANGE_NAME,
         market_type,
@@ -107,12 +112,13 @@ fn test_crawl_l2_snapshot_without_symbol(market_type: MarketType) {
     )
 }
 
-#[test_case(MarketType::Spot, "BTC-USDT"; "inconclusive")]
+// #[test_case(MarketType::Spot, "BTC-USDT"; "ignore")]
 #[test_case(MarketType::InverseSwap, "XBTUSDM")]
 #[test_case(MarketType::LinearSwap, "XBTUSDTM")]
-#[test_case(MarketType::InverseFuture, "XBTMH22")]
-fn test_crawl_l3_snapshot(market_type: MarketType, symbol: &str) {
-    test_one_symbol!(
+#[test_case(MarketType::InverseFuture, "XBTMM22")]
+#[tokio::test(flavor = "multi_thread")]
+async fn test_crawl_l3_snapshot(market_type: MarketType, symbol: &str) {
+    test_crawl_restful!(
         crawl_l3_snapshot,
         EXCHANGE_NAME,
         market_type,
@@ -124,8 +130,9 @@ fn test_crawl_l3_snapshot(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::Spot, "BTC-USDT")]
 #[test_case(MarketType::InverseSwap, "XBTUSDM")]
 #[test_case(MarketType::LinearSwap, "XBTUSDTM")]
-#[test_case(MarketType::InverseFuture, "XBTMH22")]
-fn test_crawl_ticker(market_type: MarketType, symbol: &str) {
+#[test_case(MarketType::InverseFuture, "XBTMM22")]
+#[tokio::test(flavor = "multi_thread")]
+async fn test_crawl_ticker(market_type: MarketType, symbol: &str) {
     test_one_symbol!(
         crawl_ticker,
         EXCHANGE_NAME,
@@ -139,6 +146,7 @@ fn test_crawl_ticker(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::InverseSwap)]
 #[test_case(MarketType::LinearSwap)]
 #[test_case(MarketType::InverseFuture)]
-fn test_crawl_candlestick(market_type: MarketType) {
+#[tokio::test(flavor = "multi_thread")]
+async fn test_crawl_candlestick(market_type: MarketType) {
     gen_test_crawl_candlestick!(EXCHANGE_NAME, market_type)
 }
