@@ -13,7 +13,8 @@ const EXCHANGE_NAME: &str = "zbg";
 #[test_case(MarketType::Spot, "btc_usdt")]
 // #[test_case(MarketType::InverseSwap, "BTC_USD-R")]
 // #[test_case(MarketType::LinearSwap, "BTC_USDT")]
-fn test_crawl_trade(market_type: MarketType, symbol: &str) {
+#[tokio::test(flavor = "multi_thread")]
+async fn test_crawl_trade(market_type: MarketType, symbol: &str) {
     test_one_symbol!(
         crawl_trade,
         EXCHANGE_NAME,
@@ -26,7 +27,8 @@ fn test_crawl_trade(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::Spot, "btc_usdt")]
 // #[test_case(MarketType::InverseSwap, "BTC_USD-R")]
 // #[test_case(MarketType::LinearSwap, "BTC_USDT")]
-fn test_crawl_l2_event(market_type: MarketType, symbol: &str) {
+#[tokio::test(flavor = "multi_thread")]
+async fn test_crawl_l2_event(market_type: MarketType, symbol: &str) {
     test_one_symbol!(
         crawl_l2_event,
         EXCHANGE_NAME,
@@ -40,7 +42,7 @@ fn test_crawl_l2_event(market_type: MarketType, symbol: &str) {
 // #[test_case(MarketType::InverseSwap, "BTC_USD-R")]
 // #[test_case(MarketType::LinearSwap, "BTC_USDT")]
 fn test_crawl_l2_snapshot(market_type: MarketType, symbol: &str) {
-    test_one_symbol!(
+    test_crawl_restful!(
         crawl_l2_snapshot,
         EXCHANGE_NAME,
         market_type,
@@ -53,7 +55,7 @@ fn test_crawl_l2_snapshot(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::InverseSwap)]
 #[test_case(MarketType::LinearSwap)]
 fn test_crawl_l2_snapshot_without_symbol(market_type: MarketType) {
-    test_all_symbols!(
+    test_crawl_restful_all_symbols!(
         crawl_l2_snapshot,
         EXCHANGE_NAME,
         market_type,
@@ -64,7 +66,8 @@ fn test_crawl_l2_snapshot_without_symbol(market_type: MarketType) {
 #[test_case(MarketType::Spot, "btc_usdt")]
 // #[test_case(MarketType::InverseSwap, "BTC_USD-R")]
 // #[test_case(MarketType::LinearSwap, "BTC_USDT")]
-fn test_crawl_ticker(market_type: MarketType, symbol: &str) {
+#[tokio::test(flavor = "multi_thread")]
+async fn test_crawl_ticker(market_type: MarketType, symbol: &str) {
     test_one_symbol!(
         crawl_ticker,
         EXCHANGE_NAME,
@@ -77,6 +80,7 @@ fn test_crawl_ticker(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::Spot)]
 #[test_case(MarketType::InverseSwap)]
 #[test_case(MarketType::LinearSwap)]
-fn test_crawl_candlestick(market_type: MarketType) {
+#[tokio::test(flavor = "multi_thread")]
+async fn test_crawl_candlestick(market_type: MarketType) {
     gen_test_crawl_candlestick!(EXCHANGE_NAME, market_type)
 }
